@@ -64,11 +64,16 @@ def sensitivity(var, xlabel="time", model=None, var0=None, t =None, param=None,
         C_sens = sol_ode(model, var0, t, param_new)
     # calculate the sensitivity of the parameter along the time or length
     if xlabel == "time":
-        try:
-            result = var*(C_sens - C) / (0.0001 * var)
-        except:
-            result = var*(C_sens[col_index]- C[col_index])/(0.0001 * var)
-        
+        if var == 0:
+            try:
+                result = var*(C_sens - C) / (0.0001)
+            except:
+                result = var*(C_sens[col_index]- C[col_index])/(0.0001)
+        else:
+            try:
+                result = var*(C_sens - C) / (0.0001 * var)
+            except:
+                result = var*(C_sens[col_index]- C[col_index])/(0.0001 * var)        
         # plot the results
         plt.figure('sensitivity')
         plt.grid()
@@ -82,8 +87,9 @@ def sensitivity(var, xlabel="time", model=None, var0=None, t =None, param=None,
         
         return result
     elif xlabel == "length":
-        
-        result = var*(C_sens[-1,:] - C[-1,:]) / (0.0001 * var)
+        if var == 0: result = var * (C_sens[-1,:] - C[-1,:]) / (0.0001)
+        else:
+            result = var*(C_sens[-1,:] - C[-1,:]) / (0.0001 * var)
         
         # plot the results
         plt.figure('sensitivity')
