@@ -5,7 +5,7 @@ from .sol_ode import sol_ode
 from .delay import delay
 from .two_position import two_position
 
-def two_pos_controller(model, var0, t, param, Tt, xlimit, ylimit, x_index = -1, y_index = -1):
+def two_pos_controller(model, var0, t, param, Tt, xlimit, ylimit, x_index = -1, y_index = -1, n = 1, n_meas = 0)):
     
     """
     Create a two position controller to adjust the parameter of input ode function,
@@ -35,7 +35,7 @@ def two_pos_controller(model, var0, t, param, Tt, xlimit, ylimit, x_index = -1,
     results = list(range(len(t)))
 
     #  store the value calculated from last time.
-    for i in tq.tqdm(range(len(t)),position=0,leave=True):
+    for i in tq.tqdm(range(len(t)-1),position=0,leave=True):
         
         y_final[i] = y
         param[y_index] = y
@@ -46,17 +46,30 @@ def two_pos_controller(model, var0, t, param, Tt, xlimit, ylimit, x_index = -1,
         # save the solved results, drop the duplicated value with the same time index,
         # only keeping the last one.
         
-        results[i] = np.transpose(df)[-1]
-        var0 = np.transpose(df)[-1]
-        x[i] = df[x_index][-1]
+        if n == 1:
+            results[i] = np.transpose(df)[-1]
+            var0 = np.transpose(df)[-1]
+            x[i] = df[x_index][-1]
+        else:
+            results[i] =np.array(df)[:,-1]
+            var0 = np.array(df)[:,-1]
+            x[i] = df[x_index][-1,n_meas-1]
         
         if Tt != 0:
-            x_delay = delay(t, x, Tt, value = 0)
+            x_delay = sh.delay(t, x, Tt, value = 0)
 
         else:
             x_delay = x
 
-        # control the y value by teo position controller.
+        # control the y value by two position controller.
         y = two_position(x_delay[i], y, xlimit, ylimit)
-        
-    return np.transpose(results), y_final
\ No newline at end of file
+    
+    y_final[len(time)-1] = y_final[len(t)-2]
+    results[len(time)-1] = results[len(time)-2]
+    
+    if n != 1: 
+        r = np.array(results)
+        results = r.transpose(1,0,2)
+    else: results = np.transpose(results)
+    
+    return results, y_final
\ No newline at end of file
